summaryrefslogtreecommitdiffstats
path: root/karbon/core/vgroup.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /karbon/core/vgroup.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'karbon/core/vgroup.h')
-rw-r--r--karbon/core/vgroup.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/karbon/core/vgroup.h b/karbon/core/vgroup.h
index 29eb3842..dbb3d326 100644
--- a/karbon/core/vgroup.h
+++ b/karbon/core/vgroup.h
@@ -35,14 +35,14 @@ class KARBONBASE_EXPORT VGroup : public VObject
{
public:
/**
* Constructs a new group object that is child of tqparent and has the given state.
*
* The object's fill and stroke are created here.
*
* @param tqparent the new object's tqparent
* @param state the new object's state
*/
- VGroup( VObject* tqparent, VState state = normal );
+ VGroup( VObject* parent, VState state = normal );
/**
* Copy constructor.
@@ -35,14 +35,14 @@ class KARBONBASE_EXPORT VGroup : public VObject
public:
/**
- * Constructs a new group object that is child of tqparent and has the given state.
+ * Constructs a new group object that is child of parent and has the given state.
*
* The object's fill and stroke are created here.
@@ -35,14 +35,14 @@ class KARBONBASE_EXPORT VGroup : public VObject
* The object's fill and stroke are created here.
*
- * @param tqparent the new object's tqparent
+ * @param parent the new object's parent
* @param state the new object's state
*/